
__version__ = "0.11.2"
__version_vcs_info__ = {
    'branch': 'hotfix-0.11.2',
    'revid': 'b67dde5',
    'revno': 1918}
__version_user_email__ = "saxtouri@admin.grnet.gr"
__version_user_name__ = "Stavros Sachtouris"
